==> zio-aws-ec2_2.13-5.17.123.1-sources.jar: zio/aws/ec2/model/GetNetworkInsightsAccessScopeContentResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetNetworkInsightsAccessScopeContentResponse(
    networkInsightsAccessScopeContent: Option[
      zio.aws.ec2.model.NetworkInsightsAccessScopeContent
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetNetworkInsightsAccessScopeContentResponse = {
    import GetNetworkInsightsAccessScopeContentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetNetworkInsightsAccessScopeContentResponse
      .builder()
      .optionallyWith(
        networkInsightsAccessScopeContent.map(value => value.buildAwsValue())
      )(_.networkInsightsAccessScopeContent)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.GetNetworkInsightsAccessScopeContentResponse.ReadOnly =
    zio.aws.ec2.model.GetNetworkInsightsAccessScopeContentResponse
      .wrap(buildAwsValue())
}
object GetNetworkInsightsAccessScopeContentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetNetworkInsightsAccessScopeContentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.GetNetworkInsightsAccessScopeContentResponse =
      zio.aws.ec2.model.GetNetworkInsightsAccessScopeContentResponse(
        networkInsightsAccessScopeContent.map(value => value.asEditable)
      )
    def networkInsightsAccessScopeContent
        : Option[zio.aws.ec2.model.NetworkInsightsAccessScopeContent.ReadOnly]
    def getNetworkInsightsAccessScopeContent: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.NetworkInsightsAccessScopeContent.ReadOnly
    ] = AwsError.unwrapOptionField(
      "networkInsightsAccessScopeContent",
      networkInsightsAccessScopeContent
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetNetworkInsightsAccessScopeContentResponse
  ) extends zio.aws.ec2.model.GetNetworkInsightsAccessScopeContentResponse.ReadOnly {
    override val networkInsightsAccessScopeContent
        : Option[zio.aws.ec2.model.NetworkInsightsAccessScopeContent.ReadOnly] =
      scala
        .Option(impl.networkInsightsAccessScopeContent())
        .map(value =>
          zio.aws.ec2.model.NetworkInsightsAccessScopeContent.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetNetworkInsightsAccessScopeContentResponse
  ): zio.aws.ec2.model.GetNetworkInsightsAccessScopeContentResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-6.20.78.1-sources.jar: zio/aws/ec2/model/GetNetworkInsightsAccessScopeContentResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetNetworkInsightsAccessScopeContentResponse(
    networkInsightsAccessScopeContent: Optional[
      zio.aws.ec2.model.NetworkInsightsAccessScopeContent
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.GetNetworkInsightsAccessScopeContentResponse = {
    import GetNetworkInsightsAccessScopeContentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.GetNetworkInsightsAccessScopeContentResponse
      .builder()
      .optionallyWith(
        networkInsightsAccessScopeContent.map(value => value.buildAwsValue())
      )(_.networkInsightsAccessScopeContent)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.GetNetworkInsightsAccessScopeContentResponse.ReadOnly =
    zio.aws.ec2.model.GetNetworkInsightsAccessScopeContentResponse
      .wrap(buildAwsValue())
}
object GetNetworkInsightsAccessScopeContentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.GetNetworkInsightsAccessScopeContentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.GetNetworkInsightsAccessScopeContentResponse =
      zio.aws.ec2.model.GetNetworkInsightsAccessScopeContentResponse(
        networkInsightsAccessScopeContent.map(value => value.asEditable)
      )
    def networkInsightsAccessScopeContent
        : Optional[zio.aws.ec2.model.NetworkInsightsAccessScopeContent.ReadOnly]
    def getNetworkInsightsAccessScopeContent: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.NetworkInsightsAccessScopeContent.ReadOnly
    ] = AwsError.unwrapOptionField(
      "networkInsightsAccessScopeContent",
      networkInsightsAccessScopeContent
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.GetNetworkInsightsAccessScopeContentResponse
  ) extends zio.aws.ec2.model.GetNetworkInsightsAccessScopeContentResponse.ReadOnly {
    override val networkInsightsAccessScopeContent: Optional[
      zio.aws.ec2.model.NetworkInsightsAccessScopeContent.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.networkInsightsAccessScopeContent())
      .map(value =>
        zio.aws.ec2.model.NetworkInsightsAccessScopeContent.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.GetNetworkInsightsAccessScopeContentResponse
  ): zio.aws.ec2.model.GetNetworkInsightsAccessScopeContentResponse.ReadOnly =
    new Wrapper(impl)
}
